'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _react3 = require('@momentum-ui/react');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var styles = {
  'controlContainer': 'controlContainer--1zPXQ',
  'controlItem': 'controlItem--Jb6Vr',
  'button': 'button--146DH'
}; // @related-file ./styles.css

var propTypes = {
  buttons: _propTypes2.default.arrayOf(_propTypes2.default.shape({
    accessibilityLabel: _propTypes2.default.string,
    label: _propTypes2.default.string,
    buttonClassName: _propTypes2.default.string,
    buttonType: _propTypes2.default.oneOfType([_propTypes2.default.oneOf(['chat', 'camera', 'meetings', 'whiteboard', 'files', 'share-screen', 'tasks', 'microphone-muted', 'camera-muted', 'cancel']), _propTypes2.default.shape({
      color: _propTypes2.default.string,
      icon: _propTypes2.default.element.isRequired
    })]),
    callControl: _propTypes2.default.bool,
    onClick: _propTypes2.default.func
  })).isRequired,
  showLabels: _propTypes2.default.bool

};

var defaultProps = {
  showLabels: false
};

function ButtonControls(props) {
  var buttons = props.buttons,
      showLabels = props.showLabels;


  var buttonsRendered = buttons.map(function (button, idx) {
    var label = showLabels && button.label ? button.label : '';
    var ariaLabel = button.accessibilityLabel || button.label;
    var key = button.key || 'button-controls-' + idx;

    if (button.callControl) {
      return _react2.default.createElement(_react3.CallControl, {
        active: button.active,
        ariaLabel: ariaLabel,
        key: key,
        label: label,
        onClick: button.onClick,
        type: button.buttonType
      });
    }

    return _react2.default.createElement(_react3.ActivityButton, {
      active: button.active,
      ariaLabel: ariaLabel,
      key: key,
      label: label,
      onClick: button.onClick,
      type: button.buttonType
    });
  });

  return _react2.default.createElement(
    'div',
    { className: (0, _classnames2.default)('ciscospark-controls-container', styles.controlContainer) },
    buttonsRendered
  );
}

ButtonControls.propTypes = propTypes;
ButtonControls.defaultProps = defaultProps;

exports.default = ButtonControls;